=======
Credits
=======

Development Leads
-----------------

- `Greg Tucker <https://github.com/gregtucker>`_
- `Nicole Gasparini <https://github.com/nicgaspar>`_
- `Erkan Istanbulluoglu <https://github.com/erkanistan>`_
- `Daniel Hobley <https://github.com/SiccarPoint>`_
- `Sai S. Nudurupati <https://github.com/saisiddu>`_
- `Jordan Adams <https://github.com/jadams15>`_
- `Eric Hutton <https://github.com/mcflugen>`_
- `Jenny Knuth <https://github.com/jennyknuth>`_
- `Katy Barnhart <https://github.com/kbarnhart>`_
- `Margaux Mouchene <https://github.com/margauxmouchene>`_
- `Christina Bandaragoda <https://github.com/ChristinaB>`_
- `Nathan Lyons <https://github.com/nathanlyons>`_

Contributors
------------

- `Charlie Shobe <https://github.com/cmshobe>`_
- `Ronda Strauch <https://github.com/RondaStrauch>`_
- `David Litwin <https://github.com/DavidLitwin>`_
- `Rachel Glade <https://github.com/Glader011235>`_
- `Giuseppecipolla95 <https://github.com/Giuseppecipolla95>`_
- `Amanda Manaster <https://github.com/amanaster2>`_
- `elbeejay <https://github.com/elbeejay>`_
- `Allison Pfeiffer <https://github.com/pfeiffea>`_
- `alangston <https://github.com/alangston>`_
- `Kristen Thyng <https://github.com/kthyng>`_
- `Dylan Ward <https://github.com/ddoubleprime>`_
- `Benjamin Campforts  <https://github.com/BCampforts>`_
- `Sebastien Lenard <https://github.com/sebastien-lenard>`_
- `Shelby Ahrendt <https://github.com/shelbyahrendt>`_
- `Josh Wolpert <https://github.com/josh-wolpert>`_
- `Christopher Sheehan <https://github.com/Sheehace>`_
- `slundell123 <https://github.com/slundell123>`_
